@@ -7,7 +7,7 @@ use strict;
 
 package Log::Report::Template;
 use vars '$VERSION';
-$VERSION = '0.11';
+$VERSION = '0.12';
 
 use base 'Template';
 
@@ -42,8 +42,6 @@ sub _init($)
     my $incl = $args->{INCLUDE_PATH} || [];
     $self->{LRT_path} = ref $incl eq 'ARRAY' ? $incl : [ split $delim, $incl ];
 
-    $self->{LRT_dom_by_func} = {};
-
     my $handle_errors = $args->{processing_errors} || 'NATIVE';
     if($handle_errors eq 'EXCEPTION') { $self->{LRT_exceptions} = 1 }
     elsif($handle_errors ne 'NATIVE')
@@ -121,12 +119,11 @@ sub addTextdomain($%) {
     textdomain $domain;
 
     my $func    = $domain->function;
-    if(my $other = $self->_domainByFunction($func))
+    if((my $other) = grep $func eq $_->function, $self->_domains)
     {   error __x"translation function '{func}' already in use by textdomain '{name}'"
           , func => $func, name => $other->name;
     }
     $self->{LRT_domains}{$name}     = $domain;
-    $self->{LRT_dom_by_func}{$func} = $domain;
 
     # call as function or as filter
     $self->_stash->{$func}   = $domain->translationFunction($self->service);
@@ -134,11 +131,6 @@ sub addTextdomain($%) {
     $domain;
 }
 
-# _domainByFunction($function_name)
-# Which textdomain is being used is determined by the translation function
-# that is called: it's a unique relationship.
-
-sub _domainByFunction($) { $_[0]->{LRT_dom_by_func}{$_[1]} }
 sub _incl_path() { @{shift->{LRT_path}} }
 sub _filters()   { shift->{LRT_filters} }
 sub _stash()     { shift->service->context->stash }
@@ -203,7 +195,8 @@ sub _cols_factory(@)
     {   my $pattern = shift @blocks;
         return sub {   # second syntax
     	    my @cols = split /\t/, $_[0];
-    	    $pattern =~ s/\$([0-9]+)/$cols[$1-1] || ''/ger;
+    	    $pattern =~ s/\$([0-9]+)/$cols[$1-1] || ''/ge;
+			$pattern;
         }
     }
 
